<?xml version="1.0" encoding="UTF-8"?>
<!-- VZ809v1.0_VALXSLT_560u2, 02-06-2021 -->
<xsl:stylesheet version="1.0"
xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
xmlns:vbt="http://ei.vektis.nl/vz/basis/v1_0"
xmlns:vz809="http://ei.vektis.nl/vz/vz809/v1_0"
xmlns:vz810="http://ei.vektis.nl/vz/vz810/v1_0" >

 	<xsl:import href="rc8028.xslt"/> 
 	<xsl:import href="rc8986.xslt"/>
 	
	<!-- Uitvoer is vz810 bericht met Retourcodes. -->
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes" />
	
	<xsl:variable name="Berichtcode" select="//vz809:Bericht/vz809:Header/vbt:Berichtcode" />
	<xsl:variable name="BerichtSoort" select="//vz809:Bericht/vz809:Header/vbt:BerichtSoort"/> 
	<xsl:variable name="Verzenddatum" select="translate(//vz809:Bericht/vz809:Header/vbt:Verzenddatum, '-', '')"/>


	<!-- Controleer op errors in de Header -->
	<!-- retourcode 8028: Soort bericht ontbreekt of is onjuist -->
	<xsl:variable name="rc8028">
		<xsl:call-template name="rc8028">
			<xsl:with-param name="BerichtSoort" select="$BerichtSoort" />
		</xsl:call-template>
	</xsl:variable>

	<!-- retourcode 8986: Verzenddatum moet kleiner zijn dan of gelijk zijn aan de huidige datum. -->
	<xsl:variable name="rc8986">
		<xsl:call-template name="rc8986">
			<xsl:with-param name="Verzenddatum" select="$Verzenddatum" />
			<xsl:with-param name="BerichtSoort" select="$BerichtSoort" />
		</xsl:call-template>
	</xsl:variable>

	<xsl:template match="//vz809:Bericht">
		<vz810:Bericht>
			<xsl:attribute name="xsi:schemaLocation">http://ei.vektis.nl/vz/vz810/v1_0 vz810_561.xsd</xsl:attribute>
			
			<xsl:choose>
				
				<!-- Geen errors in de Header, dan hele bericht als retour -->
				<xsl:when test="$rc8028='' and $rc8986=''">
					<xsl:apply-templates select="vz809:Header"/>
					<xsl:apply-templates select="vz809:Context"/>
					<xsl:apply-templates select="vz809:Specificatieregel"/>  
  				</xsl:when>
				
				<!-- Wel errors in de Header, dan alleen Header als retour -->
				<xsl:otherwise>
					<xsl:apply-templates select="vz809:Header"/>
				</xsl:otherwise>
			</xsl:choose>
				
		</vz810:Bericht>
	</xsl:template>	
		
	<xsl:template match="vz809:Header">
		<vz810:Header>
			
			<xsl:apply-templates select="vbt:BerichtSoort" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:CrediteurOrgaan"/>
			<xsl:apply-templates select="vbt:BuitenlandsVerbindingsOrgaan"/>
			<xsl:apply-templates select="vbt:Verzenddatum" mode="copy-if-exists"/>
			<vz810:BerichtCode>561</vz810:BerichtCode>
			<xsl:apply-templates select="vz809:BerichtVersie" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz809:BerichtSubVersie" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz809:BetwistingDeclaratieReferentienummer" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz809:BetwistingDeclaratieregelReferentienummer" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz809:BijlagenAantal" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz809:BijlagenInformatie"/>
			
  	       	<vz810:Retourcodes>
					
				<xsl:copy-of select="$rc8028"/>
				<xsl:copy-of select="$rc8986"/>
					
				<!-- Wanneer de klasse correct is dan wordt een 0200 retourcode toegevoegd. -->
				<xsl:if test="$rc8028='' and $rc8986=''">
					<vbt:Retourcode>0200</vbt:Retourcode>
				</xsl:if>
				
			</vz810:Retourcodes>
  	       	
		</vz810:Header>
	</xsl:template>
		
	<xsl:template match="vz809:BijlagenInformatie">	
		<vz810:BijlagenInformatie>
			<xsl:apply-templates select="vbt:BijlageNaam"/>
		</vz810:BijlagenInformatie>
	</xsl:template>

	<xsl:template match="vbt:BijlageNaam">	
		<vbt:BijlageNaam>
			<xsl:apply-templates select="vbt:Id" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Naam" mode="copy-if-exists"/>
		</vbt:BijlageNaam>
	</xsl:template>	
		
	<xsl:template match="vz809:Context">
		<vz810:Context>
			
			<xsl:apply-templates select="vz809:DeclaratieReferentienummer" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz809:DeclaratieregelReferentienummer" mode="copy-if-exists"/>
			
  	       	<vz810:Retourcodes>
				<!-- retourcode is altijd 0200 voor Context voor berichtcode 560 -->
					<vbt:Retourcode>0200</vbt:Retourcode>
			</vz810:Retourcodes>
  	       	
		</vz810:Context>
	</xsl:template>	
	
	<xsl:template match="vz809:Specificatieregel">
		<vz810:Specificatieregel>
			
			<xsl:apply-templates select="vz809:DebiteurOrgaan"/>
			<xsl:apply-templates select="vz809:Persoonsgegevens"/>
			<xsl:apply-templates select="vz809:Details"/>	
			
 	       	<vz810:Retourcodes>
				<!-- retourcode is altijd 0200 voor Specificatieregel voor berichtcode 560 -->
					<vbt:Retourcode>0200</vbt:Retourcode>
			</vz810:Retourcodes>
   	       	
		</vz810:Specificatieregel>
	</xsl:template>		
	
	<xsl:template match="vbt:CrediteurOrgaan">	
		<vbt:CrediteurOrgaan>
			<xsl:apply-templates select="vbt:Orgaancode" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Landcode" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Naam" mode="copy-if-exists"/>
		</vbt:CrediteurOrgaan>
	</xsl:template>
	
	<xsl:template match="vbt:BuitenlandsVerbindingsOrgaan">	
		<vbt:BuitenlandsVerbindingsOrgaan>
			<xsl:apply-templates select="vbt:Orgaancode" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Landcode" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Naam" mode="copy-if-exists"/>
		</vbt:BuitenlandsVerbindingsOrgaan>
	</xsl:template>

	<xsl:template match="vz809:DebiteurOrgaan">	
		<vz810:DebiteurOrgaan>
			<xsl:apply-templates select="vbt:Orgaancode" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Landcode" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Naam" mode="copy-if-exists"/>
		</vz810:DebiteurOrgaan>
	</xsl:template>
	
	<xsl:template match="vz809:Persoonsgegevens">	
		<vz810:Persoonsgegevens>
			<xsl:apply-templates select="vbt:PINVerzekeringsland" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:PINWoonlandofVerblijfsland" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Familienaam" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:FamilienaamGeboorte" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Voornamen" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:VoornamenGeboorte" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Geboortedatum" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:GeslachtCode" mode="copy-if-exists"/>
		</vz810:Persoonsgegevens>
	</xsl:template>		
		
	<xsl:template match="vz809:Details">	
		<vz810:Details>
			<xsl:apply-templates select="vz809:Betwistingscode" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz809:AanvullendeInfo"/>
			<xsl:apply-templates select="vz809:BedragBetwisting"/>
		</vz810:Details>
	</xsl:template>		

	<xsl:template match="vz809:AanvullendeInfo">	
		<vz810:AanvullendeInfo>
			<xsl:apply-templates select="vz809:DatumBetwistingscode" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz809:Overig" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz809:DubbeleFactuur"/>
		</vz810:AanvullendeInfo>
	</xsl:template>	

	<xsl:template match="vz809:BedragBetwisting">	
		<vz810:BedragBetwisting>
			<xsl:apply-templates select="vbt:Bedrag" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Valuta" mode="copy-if-exists"/>
		</vz810:BedragBetwisting>
	</xsl:template>			

	<xsl:template match="vz809:DubbeleFactuur">	
		<vz810:DubbeleFactuur>
			<xsl:apply-templates select="vz809:DeclaratieReferentienummer" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz809:DeclaratieregelReferentienummer" mode="copy-if-exists"/>
		</vz810:DubbeleFactuur>
	</xsl:template>			

	<!-- Copy template: als een enkel element voorkomt is, wordt deze gekopieerd in de opgegeven namespace -->
	<xsl:template match="vz809:*" mode="copy-if-exists">
		<xsl:param name="NameSpacePrefix" select="'vz810:'"/>
		<xsl:if test=".">
			<xsl:element name="{concat($NameSpacePrefix,local-name())}">
				<xsl:value-of select="text()"/>
			</xsl:element>
		</xsl:if>
	</xsl:template>
	<xsl:template match="*[not(starts-with(name(), 'vz809:'))]" mode="copy-if-exists">
        <xsl:if test=".">
            <xsl:element name="{name()}">
				<xsl:value-of select="text()"/>
            </xsl:element>
        </xsl:if>
	</xsl:template>

</xsl:stylesheet>